==> jc-1.4.0.tar.gz: jas/Var.h <==
// public class jas.Var

// class file dependencies
// @dep_class b289122de44c06fb jas_Var
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_jas_Var_H_
#define _JC_jas_Var_H_

// Forward structure declarations
struct _jc_jas_CP$object;
struct _jc_jas_ClassEnv$object;
struct _jc_jas_ConstAttr$object;
struct _jc_jas_GenericAttr$object;
struct _jc_java_io_DataOutputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_util_Vector$object;

// Typedefs
typedef struct _jc_jas_Var$sub_refs	_jc_jas_Var$sub_refs;
typedef struct _jc_jas_Var$sub_nonrefs	_jc_jas_Var$sub_nonrefs;
typedef struct _jc_jas_Var$refs	_jc_jas_Var$refs;
typedef struct _jc_jas_Var$nonrefs	_jc_jas_Var$nonrefs;
typedef struct _jc_jas_Var$object	_jc_jas_Var$object;

typedef const struct _jc_jas_Var$vmethods	_jc_jas_Var$vmethods;
typedef const struct _jc_jas_Var$vtable	_jc_jas_Var$vtable;
typedef const struct _jc_jas_Var$vtype	_jc_jas_Var$vtype;

// Constructors
extern void _jc_jas_Var$method$_init$63d743fc78e72999(_jc_env *, struct _jc_jas_Var$object *, jshort, struct _jc_jas_CP$object *, struct _jc_jas_CP$object *, struct _jc_jas_ConstAttr$object *);

// Virtual methods
extern void _jc_jas_Var$method$addGenericAttr$f87e320913bf4085(_jc_env *, struct _jc_jas_Var$object *, struct _jc_jas_GenericAttr$object *);
extern void _jc_jas_Var$method$resolve$f7bbca8128967cc2(_jc_env *, struct _jc_jas_Var$object *, struct _jc_jas_ClassEnv$object *);
extern void _jc_jas_Var$method$write$c5719140f8114b75(_jc_env *, struct _jc_jas_Var$object *, struct _jc_jas_ClassEnv$object *, struct _jc_java_io_DataOutputStream$object *);

// Virtual method descriptors
extern _jc_method _jc_jas_Var$method_info$addGenericAttr$f87e320913bf4085;
extern _jc_method _jc_jas_Var$method_info$resolve$f7bbca8128967cc2;
extern _jc_method _jc_jas_Var$method_info$write$c5719140f8114b75;

// Virtual methods structure
struct _jc_jas_Var$vmethods {
	void	(*addGenericAttr$f87e320913bf4085)(_jc_env *, struct _jc_jas_Var$object *, struct _jc_jas_GenericAttr$object *);
	void	(*resolve$f7bbca8128967cc2)(_jc_env *, struct _jc_jas_Var$object *, struct _jc_jas_ClassEnv$object *);
	void	(*write$c5719140f8114b75)(_jc_env *, struct _jc_jas_Var$object *, struct _jc_jas_ClassEnv$object *, struct _jc_java_io_DataOutputStream$object *);
};

// Vtable
struct _jc_jas_Var$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_jas_Var$vmethods	jas_Var;
};

// Vtype
struct _jc_jas_Var$vtype {
	_jc_type			type;
	_jc_jas_Var$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_jas_Var$sub_refs {
	struct _jc_jas_CP$object	*name;
	struct _jc_jas_CP$object	*sig;
	struct _jc_jas_ConstAttr$object	*const__5fattr;
	struct _jc_java_util_Vector$object	*genericAttrs;
};

// Reference instance fields (object)
struct _jc_jas_Var$refs {
    _jc_jas_Var$sub_refs	jas_Var;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_jas_Var$sub_nonrefs {
	jshort	var__5facc;
};

// Non-reference instance fields (object)
struct _jc_jas_Var$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_jas_Var$sub_nonrefs	jas_Var;
};

// Object instance structure
struct _jc_jas_Var$object {
	_jc_jas_Var$refs	refs[0];
	_jc_word		lockword;
	_jc_jas_Var$vtype	*vtype;
	_jc_jas_Var$nonrefs	nonrefs;
};

// Type structure
extern _jc_jas_Var$vtype _jc_jas_Var$type;

// Array types class info structures
_JC_DECL_ARRAYS(jas_Var, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_jas_Var$class_object;

#endif	/* _JC_jas_Var_H_ */

==> jc-1.4.6.tar.gz: jas/Var.h <==
// public class jas.Var

// class file dependencies
// @dep_class b289122de44c06fb jas_Var
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_jas_Var_H_
#define _JC_jas_Var_H_

// Forward structure declarations
struct _jc_jas_CP$object;
struct _jc_jas_ClassEnv$object;
struct _jc_jas_ConstAttr$object;
struct _jc_jas_GenericAttr$object;
struct _jc_java_io_DataOutputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_util_Vector$object;

// Typedefs
typedef struct _jc_jas_Var$sub_refs	_jc_jas_Var$sub_refs;
typedef struct _jc_jas_Var$sub_nonrefs	_jc_jas_Var$sub_nonrefs;
typedef struct _jc_jas_Var$refs	_jc_jas_Var$refs;
typedef struct _jc_jas_Var$nonrefs	_jc_jas_Var$nonrefs;
typedef struct _jc_jas_Var$object	_jc_jas_Var$object;

typedef const struct _jc_jas_Var$vmethods	_jc_jas_Var$vmethods;
typedef const struct _jc_jas_Var$vtable	_jc_jas_Var$vtable;
typedef const struct _jc_jas_Var$vtype	_jc_jas_Var$vtype;

// Constructors
extern void _jc_jas_Var$method$_init$63d743fc78e72999(_jc_env *, struct _jc_jas_Var$object *, jshort, struct _jc_jas_CP$object *, struct _jc_jas_CP$object *, struct _jc_jas_ConstAttr$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_jas_Var$method$addGenericAttr$f87e320913bf4085(_jc_env *, struct _jc_jas_Var$object *, struct _jc_jas_GenericAttr$object *) _JC_JCNI_ATTR;
extern void _jc_jas_Var$method$resolve$f7bbca8128967cc2(_jc_env *, struct _jc_jas_Var$object *, struct _jc_jas_ClassEnv$object *) _JC_JCNI_ATTR;
extern void _jc_jas_Var$method$write$c5719140f8114b75(_jc_env *, struct _jc_jas_Var$object *, struct _jc_jas_ClassEnv$object *, struct _jc_java_io_DataOutputStream$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_jas_Var$method_info$addGenericAttr$f87e320913bf4085;
extern _jc_method _jc_jas_Var$method_info$resolve$f7bbca8128967cc2;
extern _jc_method _jc_jas_Var$method_info$write$c5719140f8114b75;

// Virtual methods structure
struct _jc_jas_Var$vmethods {
	void	(*addGenericAttr$f87e320913bf4085)(_jc_env *, struct _jc_jas_Var$object *, struct _jc_jas_GenericAttr$object *) _JC_JCNI_ATTR;
	void	(*resolve$f7bbca8128967cc2)(_jc_env *, struct _jc_jas_Var$object *, struct _jc_jas_ClassEnv$object *) _JC_JCNI_ATTR;
	void	(*write$c5719140f8114b75)(_jc_env *, struct _jc_jas_Var$object *, struct _jc_jas_ClassEnv$object *, struct _jc_java_io_DataOutputStream$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_jas_Var$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_jas_Var$vmethods	jas_Var;
};

// Vtype
struct _jc_jas_Var$vtype {
	_jc_type			type;
	_jc_jas_Var$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_jas_Var$sub_refs {
	struct _jc_jas_CP$object	*name;
	struct _jc_jas_CP$object	*sig;
	struct _jc_jas_ConstAttr$object	*const__5fattr;
	struct _jc_java_util_Vector$object	*genericAttrs;
};

// Reference instance fields (object)
struct _jc_jas_Var$refs {
    _jc_jas_Var$sub_refs	jas_Var;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_jas_Var$sub_nonrefs {
	jshort	var__5facc;
};

// Non-reference instance fields (object)
struct _jc_jas_Var$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_jas_Var$sub_nonrefs	jas_Var;
};

// Object instance structure
struct _jc_jas_Var$object {
	_jc_jas_Var$refs	refs[0];
	_jc_word		lockword;
	_jc_jas_Var$vtype	*vtype;
	_jc_jas_Var$nonrefs	nonrefs;
};

// Type structure
extern _jc_jas_Var$vtype _jc_jas_Var$type;

// Array types class info structures
_JC_DECL_ARRAYS(jas_Var, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_jas_Var$class_object;

#endif	/* _JC_jas_Var_H_ */
